@@ -1,9 +1,6 @@
 import json
 from sly import Parser
-from mindsdb_sql.parser.ast import (ASTNode, Constant, Identifier, Select, BinaryOperation, UnaryOperation, Join,
-                                    NullConstant,
-                                    TypeCast, Tuple, OrderBy, Operation, Function, Parameter, BetweenOperation, Star,
-                                    Union, Use, Show, CommonTableExpression)
+from mindsdb_sql.parser.ast import *
 from mindsdb_sql.parser.dialects.mindsdb.drop_integration import DropIntegration
 from mindsdb_sql.parser.dialects.mindsdb.drop_predictor import DropPredictor
 from mindsdb_sql.parser.dialects.mindsdb.create_predictor import CreatePredictor
@@ -27,17 +24,61 @@ class MindsDBParser(Parser):
 
     # Top-level statements
     @_('show',
+       'start_transaction',
+       'commit_transaction',
+       'rollback_transaction',
+       'alter_table',
+       'explain',
+       'set',
        'use',
        'create_predictor',
        'create_integration',
        'create_view',
        'drop_predictor',
        'drop_integration',
+       'union',
        'select',
-       'union')
+       )
     def query(self, p):
         return p[0]
 
+    # Explain
+    @_('EXPLAIN identifier')
+    def explain(self, p):
+        return Explain(target=p.identifier)
+
+    # Alter table
+    @_('ALTER TABLE identifier ID ID')
+    def alter_table(self, p):
+        return AlterTable(target=p.identifier,
+                          arg=' '.join([p.ID0, p.ID1]))
+
+    # Transactions
+
+    @_('START TRANSACTION')
+    def start_transaction(self, p):
+        return StartTransaction()
+
+    @_('COMMIT')
+    def commit_transaction(self, p):
+        return CommitTransaction()
+
+    @_('ROLLBACK')
+    def rollback_transaction(self, p):
+        return RollbackTransaction()
+
+    # Set
+
+    @_('SET AUTOCOMMIT')
+    def set(self, p):
+        return Set(category=p.AUTOCOMMIT)
+
+    @_('SET ID identifier')
+    def set(self, p):
+        if not p.ID == 'names':
+            raise ParsingException(f'Excepted "names"')
+        return Set(category=p.ID, arg=p.identifier)
+
     # Show
 
     @_('SHOW show_category show_condition_or_nothing')
@@ -312,6 +353,14 @@ class MindsDBParser(Parser):
         select.where = where_expr
         return select
 
+    # Mindsdb special case
+    @_('select FROM PREDICTORS')
+    def select(self, p):
+        select = p.select
+        ensure_select_keyword_order(select, 'FROM')
+        select.from_table = Identifier(p.PREDICTORS)
+        return select
+
     @_('select FROM from_table')
     def select(self, p):
         select = p.select
@@ -433,7 +482,7 @@ class MindsDBParser(Parser):
     def expr(self, p):
         args = p.expr_list_or_nothing
         if not args:
-            args = tuple()
+            args = []
         return Function(op=p.ID, args=args)
 
     # arguments are optional in functions, so that things like `select database()` are possible
