@@ -1,9 +1,6 @@
 from sly import Parser
 
-from mindsdb_sql.parser.ast import (ASTNode, Constant, Identifier, Select, BinaryOperation, UnaryOperation, Join,
-                                    NullConstant,
-                                    TypeCast, Tuple, OrderBy, Operation, Function, Parameter, BetweenOperation, Star,
-                                    Union, Use, Show, CommonTableExpression)
+from mindsdb_sql.parser.ast import *
 from mindsdb_sql.exceptions import ParsingException
 from mindsdb_sql.parser.lexer import SQLLexer
 from mindsdb_sql.utils import ensure_select_keyword_order, JoinType
@@ -21,11 +18,56 @@ class SQLParser(Parser):
 
     # Top-level statements
     @_('show',
+       'start_transaction',
+       'commit_transaction',
+       'rollback_transaction',
+       'alter_table',
+       'explain',
+       'set',
+       'use',
        'union',
-       'select',)
+       'select',
+       )
     def query(self, p):
         return p[0]
 
+    # Explain
+    @_('EXPLAIN identifier')
+    def explain(self, p):
+        return Explain(target=p.identifier)
+
+    # Alter table
+    @_('ALTER TABLE identifier ID ID')
+    def alter_table(self, p):
+        return AlterTable(target=p.identifier,
+                          arg=' '.join([p.ID0, p.ID1]))
+
+    # Transactions
+
+    @_('START TRANSACTION')
+    def start_transaction(self, p):
+        return StartTransaction()
+
+    @_('COMMIT')
+    def commit_transaction(self, p):
+        return CommitTransaction()
+
+    @_('ROLLBACK')
+    def rollback_transaction(self, p):
+        return RollbackTransaction()
+
+    # Set
+
+    @_('SET AUTOCOMMIT')
+    def set(self, p):
+        return Set(category=p.AUTOCOMMIT)
+
+    @_('SET ID identifier')
+    def set(self, p):
+        if not p.ID == 'names':
+            raise ParsingException(f'Excepted "names"')
+        return Set(category=p.ID, arg=p.identifier)
+
     # Show
 
     @_('SHOW show_category show_condition_or_nothing')
@@ -332,7 +374,7 @@ class SQLParser(Parser):
     def expr(self, p):
         args = p.expr_list_or_nothing
         if not args:
-            args = tuple()
+            args = []
         return Function(op=p.ID, args=args)
 
     # arguments are optional in functions, so that things like `select database()` are possible
